import os

try:
    from django.conf import settings
except ModuleNotFoundError:
    settings = object()

FACEBOOK_LOGIN_BASE_URL = getattr(settings, "FACEBOOK_LOGIN_BASE_URL", "https://facebook.com")

GRAPH_API_BASE_URL = getattr(settings, "GRAPH_API_BASE_URL", "https://graph.facebook.com")

GRAPH_API_VERSION = getattr(settings, "GRAPH_API_VERSION", "v14.0")

GRAPH_API_URL = os.path.join(GRAPH_API_BASE_URL, GRAPH_API_VERSION)

FACEBOOK_LOGIN_URL = os.path.join(FACEBOOK_LOGIN_BASE_URL, GRAPH_API_VERSION)

DEFAULT_CHUNK_SIZE = 5



import requests
from instagram_sync.core import settings


def get_user_pages(access_token):
    url = f"{settings.GRAPH_API_URL}/me/accounts?access_token={access_token}"

    response = requests.get(url)

    return response.json()


def get_page_instagram_accounts(page_id, access_token):
    url = f"{settings.GRAPH_API_URL}/{page_id}?fields=instagram_business_account&access_token={access_token}"

    response = requests.get(url)

    return response.json()
